@@ -2,6 +2,7 @@
 #include <clutter/clutter.h>
 
 #include <clutter-gtk/gtk-clutter-embed.h>
+#include <clutter-gtk/gtk-clutter-util.h>
 
 typedef struct {
 
@@ -63,20 +64,8 @@ on_opacity_changed (GtkSpinButton *button, EventApp *app)
 static void
 create_colors (EventApp *app, ClutterColor *stage, ClutterColor *text)
 {
-  GtkStyle *style = gtk_widget_get_style (app->window);
-  GdkColor color;
-
-  /* Set the stage color to base[NORMAL] */
-  color = style->bg[GTK_STATE_NORMAL];
-  stage->red = (guint8) ((color.red/65535.0) * 255);
-  stage->green = (guint8) ((color.green/65535.0) * 255);
-  stage->blue  = (guint8) ((color.blue/65535.0) * 255);
-  
-  /* Now the text color */
-  color = style->text[GTK_STATE_NORMAL];
-  text->red =(guint8) ((color.red/65535.0) * 255);
-  text->green = (guint8) ((color.green/65535.0) * 255);
-  text->blue = (guint8) ((color.blue/65535.0) * 255);
+  gtk_clutter_get_bg_color (app->window, GTK_STATE_NORMAL, stage);
+  gtk_clutter_get_text_color (app->window, GTK_STATE_NORMAL, text);
 }
 
 static gboolean
@@ -118,9 +107,8 @@ main (gint argc, gchar **argv)
   ClutterColor   stage_color = {255, 255, 255, 255};
   ClutterColor   text_color = {0, 0, 0, 255};
 
-  clutter_init (&argc, &argv);
-  
-  gtk_init (&argc, &argv);
+  if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
+    g_error ("Unable to initialize GtkClutter");
 
   /* Create the inital gtk window and widgets, just like normal */
   widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -160,7 +148,7 @@ main (gint argc, gchar **argv)
   if (pixbuf == NULL)
     g_error ("Unable to load pixbuf\n");
 
-  actor = clutter_texture_new_from_pixbuf (pixbuf);
+  actor = gtk_clutter_texture_new_from_pixbuf (pixbuf);
   app->hand = actor;
   clutter_group_add (CLUTTER_GROUP (app->stage), actor);
   clutter_actor_get_size (actor, &width, &height);
@@ -216,9 +204,13 @@ main (gint argc, gchar **argv)
   gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
   g_signal_connect (button, "value-changed", G_CALLBACK (on_opacity_changed), app);
 
-  clutter_actor_show_all (app->stage);
   gtk_widget_show_all (app->window);
 
+  /* Only show/show_all the stage after parent show. widget_show will call
+   * show on the stage.
+  */
+  clutter_actor_show_all (app->stage);
+
   gtk_main ();
   
   return 0;
